# Contributing to pymc_bart
This document outlines only the most common contributions. More information coming soon.
We welcome a wide range of contributions, not only code!

## Reporting issues
If you encounter any bug or incorrect behaviour while using pymc_bart,
please report an issue to our [issue tracker](https://github.com/pymc-devs/pymc-bart/issues).
Please include any supporting information, in particular the version of
pymc_bart that you are using.
The issue tracker has several templates available to help in writing the issue
and including useful supporting information.

## Contributing code
Thanks for your interest in contributing code to pymc_bart!

* If this is your first time contributing to a project on GitHub, please read through our step by step guide to contributing to pymc_bart

### Adding new features
If you are interested in adding a new feature to pymc_bart,
first submit an issue using the "Feature Request" label for the community
to discuss its place and implementation within pymc_bart.
